# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: operation-init.j2

"""Auto-generated package that contains models used by the AccelByte Gaming Services Session History Service."""

__version__ = "1.14.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_get_matchmaking_d_98288e import AdminGetMatchmakingDetailBySessionID
from .admin_get_matchmaking_d_8811e8 import AdminGetMatchmakingDetailByTicketID
from .admin_query_game_sessio_2eed0b import AdminQueryGameSessionDetail
from .admin_query_matchmaking_detail import AdminQueryMatchmakingDetail
from .admin_query_party_detail import AdminQueryPartyDetail
from .admin_query_ticket_detail import AdminQueryTicketDetail
from .admin_ticket_detail_get_8ac60d import AdminTicketDetailGetByTicketID
from .get_game_session_detail import GetGameSessionDetail
from .get_party_detail import GetPartyDetail
from .public_query_game_session_me import PublicQueryGameSessionMe
